package com.hotent.uc.manager;

import com.hotent.base.manager.BaseManager;
import com.hotent.base.model.CommonResult;
import com.hotent.uc.model.OrgExternalSetting;
import com.hotent.uc.model.ScanLogin;
import com.hotent.uc.model.User;
import com.hotent.uc.params.org.OrgVo;

/**
 * 组织机构与外部系统配置关联 服务类
 *
 * @company 广州宏天软件股份有限公司
 * @author pangquan
 * @since 2020-10-30
 */
public interface OrgExternalSettingManager extends BaseManager<OrgExternalSetting> {

    /**
     * @description  添加组织参数配置
     * @author  yangzibin
     * @date    2023/12/28 14:30
     * @param	orgExtSetting
     * @return  com.hotent.base.model.CommonResult<java.lang.String>
     */
    CommonResult<String> addOrgExtSetting(OrgExternalSetting orgExtSetting) throws Exception;


    CommonResult<String> updateOrgExtSetting(OrgExternalSetting orgExtSetting) throws Exception;


    CommonResult<OrgExternalSetting> querySettingByCorpId(String orgId) throws Exception;

   OrgExternalSetting querySettingByCorpIdCode(String corpId) throws Exception;

    OrgExternalSetting querySettingByCorpIdReturn(String orgId) throws Exception;

    OrgExternalSetting queryByCorpId(String corpId) throws Exception;
}
